#[repr(C, packed(1))]pub struct boot_params {Show 35 fields
pub screen_info: screen_info,
pub apm_bios_info: apm_bios_info,
pub _pad2: [u8; 4],
pub tboot_addr: u64,
pub ist_info: ist_info,
pub acpi_rsdp_addr: u64,
pub _pad3: [u8; 8],
pub hd0_info: [u8; 16],
pub hd1_info: [u8; 16],
pub sys_desc_table: sys_desc_table,
pub olpc_ofw_header: olpc_ofw_header,
pub ext_ramdisk_image: u32,
pub ext_ramdisk_size: u32,
pub ext_cmd_line_ptr: u32,
pub _pad4: [u8; 112],
pub cc_blob_address: u32,
pub edid_info: edid_info,
pub efi_info: efi_info,
pub alt_mem_k: u32,
pub scratch: u32,
pub e820_entries: u8,
pub eddbuf_entries: u8,
pub edd_mbr_sig_buf_entries: u8,
pub kbd_status: u8,
pub secure_boot: u8,
pub _pad5: [u8; 2],
pub sentinel: u8,
pub _pad6: [u8; 1],
pub hdr: setup_header,
pub _pad7: [u8; 36],
pub edd_mbr_sig_buffer: [u32; 16],
pub e820_table: [boot_e820_entry; 128],
pub _pad8: [u8; 48],
pub eddbuf: [edd_info; 6],
pub _pad9: [u8; 276],
}Available on x86 or x86-64 only.
The x86 “zeropage” — exactly 4096 bytes.
_pad7 size is 0x290 - 0x1f1 - sizeof(setup_header) = 36 bytes.
Fields
screen_info: screen_infoapm_bios_info: apm_bios_info_pad2: [u8; 4]tboot_addr: u64ist_info: ist_infoacpi_rsdp_addr: u64_pad3: [u8; 8]hd0_info: [u8; 16]hd1_info: [u8; 16]sys_desc_table: sys_desc_tableolpc_ofw_header: olpc_ofw_headerext_ramdisk_image: u32ext_ramdisk_size: u32ext_cmd_line_ptr: u32_pad4: [u8; 112]cc_blob_address: u32edid_info: edid_infoefi_info: efi_infoalt_mem_k: u32scratch: u32e820_entries: u8eddbuf_entries: u8edd_mbr_sig_buf_entries: u8kbd_status: u8secure_boot: u8_pad5: [u8; 2]sentinel: u8_pad6: [u8; 1]hdr: setup_header_pad7: [u8; 36]edd_mbr_sig_buffer: [u32; 16]e820_table: [boot_e820_entry; 128]_pad8: [u8; 48]eddbuf: [edd_info; 6]_pad9: [u8; 276]Trait Implementations
Sourceimpl ByteValued for boot_params
impl ByteValued for boot_params
Sourcefn from_slice(data: &[u8]) -> Option<&Self>
fn from_slice(data: &[u8]) -> Option<&Self>
Converts a slice of raw data into a reference of
Self. Read moreSourcefn from_mut_slice(data: &mut [u8]) -> Option<&mut Self>
fn from_mut_slice(data: &mut [u8]) -> Option<&mut Self>
Converts a mutable slice of raw data into a mutable reference of
Self. Read moreSourcefn as_mut_slice(&mut self) -> &mut [u8] ⓘ
fn as_mut_slice(&mut self) -> &mut [u8] ⓘ
Converts a mutable reference to
self into a mutable slice of bytes. Read moreSourcefn as_bytes(&mut self) -> VolatileSlice<'_>
fn as_bytes(&mut self) -> VolatileSlice<'_>
Converts a mutable reference to
self into a VolatileSlice. This is
useful because VolatileSlice provides a Bytes<usize> implementation.Sourcefn write_all_to<W>(&self, writer: W) -> Result<(), Error>where
W: Write,
fn write_all_to<W>(&self, writer: W) -> Result<(), Error>where
W: Write,
Writes this
ByteValued’s byte representation to the given Write impl.Sourcefn read_exact_from<R>(reader: R) -> Result<Self, Error>where
R: Read,
fn read_exact_from<R>(reader: R) -> Result<Self, Error>where
R: Read,
Constructs an instance of this
ByteValued by reading from the given Read impl.Sourceimpl Clone for boot_params
impl Clone for boot_params
Sourcefn clone(&self) -> boot_params
fn clone(&self) -> boot_params
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for boot_params
Sourceimpl Debug for boot_params
impl Debug for boot_params
Sourceimpl Default for boot_params
impl Default for boot_params
Sourceimpl PartialEq for boot_params
impl PartialEq for boot_params
Sourcefn eq(&self, other: &boot_params) -> bool
fn eq(&self, other: &boot_params) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for boot_params