#[repr(C, packed(1))]pub struct setup_header {Show 39 fields
pub setup_sects: u8,
pub root_flags: u16,
pub syssize: u32,
pub ram_size: u16,
pub vid_mode: u16,
pub root_dev: u16,
pub boot_flag: u16,
pub jump: u16,
pub header: u32,
pub version: u16,
pub realmode_swtch: u32,
pub start_sys_seg: u16,
pub kernel_version: u16,
pub type_of_loader: u8,
pub loadflags: u8,
pub setup_move_size: u16,
pub code32_start: u32,
pub ramdisk_image: u32,
pub ramdisk_size: u32,
pub bootsect_kludge: u32,
pub heap_end_ptr: u16,
pub ext_loader_ver: u8,
pub ext_loader_type: u8,
pub cmd_line_ptr: u32,
pub initrd_addr_max: u32,
pub kernel_alignment: u32,
pub relocatable_kernel: u8,
pub min_alignment: u8,
pub xloadflags: u16,
pub cmdline_size: u32,
pub hardware_subarch: u32,
pub hardware_subarch_data: u64,
pub payload_offset: u32,
pub payload_length: u32,
pub setup_data: u64,
pub pref_address: u64,
pub init_size: u32,
pub handover_offset: u32,
pub kernel_info_offset: u32,
}Available on x86 or x86-64 only.
From arch/x86/include/uapi/asm/bootparam.h
Fields
setup_sects: u8root_flags: u16syssize: u32ram_size: u16vid_mode: u16root_dev: u16boot_flag: u16jump: u16header: u32version: u16realmode_swtch: u32start_sys_seg: u16kernel_version: u16type_of_loader: u8loadflags: u8setup_move_size: u16code32_start: u32ramdisk_image: u32ramdisk_size: u32bootsect_kludge: u32heap_end_ptr: u16ext_loader_ver: u8ext_loader_type: u8cmd_line_ptr: u32initrd_addr_max: u32kernel_alignment: u32relocatable_kernel: u8min_alignment: u8xloadflags: u16cmdline_size: u32hardware_subarch: u32hardware_subarch_data: u64payload_offset: u32payload_length: u32setup_data: u64pref_address: u64init_size: u32handover_offset: u32kernel_info_offset: u32Trait Implementations
Sourceimpl ByteValued for setup_header
impl ByteValued for setup_header
Sourcefn from_slice(data: &[u8]) -> Option<&Self>
fn from_slice(data: &[u8]) -> Option<&Self>
Converts a slice of raw data into a reference of
Self. Read moreSourcefn from_mut_slice(data: &mut [u8]) -> Option<&mut Self>
fn from_mut_slice(data: &mut [u8]) -> Option<&mut Self>
Converts a mutable slice of raw data into a mutable reference of
Self. Read moreSourcefn as_mut_slice(&mut self) -> &mut [u8] ⓘ
fn as_mut_slice(&mut self) -> &mut [u8] ⓘ
Converts a mutable reference to
self into a mutable slice of bytes. Read moreSourcefn as_bytes(&mut self) -> VolatileSlice<'_>
fn as_bytes(&mut self) -> VolatileSlice<'_>
Converts a mutable reference to
self into a VolatileSlice. This is
useful because VolatileSlice provides a Bytes<usize> implementation.Sourcefn write_all_to<W>(&self, writer: W) -> Result<(), Error>where
W: Write,
fn write_all_to<W>(&self, writer: W) -> Result<(), Error>where
W: Write,
Writes this
ByteValued’s byte representation to the given Write impl.Sourcefn read_exact_from<R>(reader: R) -> Result<Self, Error>where
R: Read,
fn read_exact_from<R>(reader: R) -> Result<Self, Error>where
R: Read,
Constructs an instance of this
ByteValued by reading from the given Read impl.Sourceimpl Clone for setup_header
impl Clone for setup_header
Sourcefn clone(&self) -> setup_header
fn clone(&self) -> setup_header
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for setup_header
Sourceimpl Debug for setup_header
impl Debug for setup_header
Sourceimpl Default for setup_header
impl Default for setup_header
Sourcefn default() -> setup_header
fn default() -> setup_header
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for setup_header
impl PartialEq for setup_header
Sourcefn eq(&self, other: &setup_header) -> bool
fn eq(&self, other: &setup_header) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for setup_header