Available on crate features
bzimage or elf or pe only.Expand description
Traits and structs for configuring and loading boot parameters.
- BootConfigurator: configure boot parameters.
- LinuxBootConfigurator: Linux boot protocol parameters configurator.
- PvhBootConfigurator: PVH boot protocol parameters configurator.
Modules
- linux
x86 or x86-64 - Traits and structs for configuring and loading boot parameters on
x86_64using the Linux boot protocol. - pvh
( bzimageorelf) and (x86 or x86-64) - Traits and structs for configuring and loading boot parameters on
x86_64using the PVH boot protocol.
Structs
- Boot
Params - Boot parameters to be written in guest memory.
Enums
- Error
- Errors specific to boot protocol configuration.
Traits
- Boot
Configurator - Trait that defines interfaces for building (TBD) and configuring boot parameters.