pub enum Error {
MemmapTableAddressMissing,
MemmapTableMissing,
MemmapTablePastRamEnd,
MemmapTableSetup,
StartInfoPastRamEnd,
StartInfoSetup,
ModulesAddressMissing,
ModulesSetup,
}Available on (crate features
bzimage or elf) and (crate features bzimage or elf or pe) and (x86 or x86-64) only.Expand description
Errors specific to the PVH boot protocol configuration.
Variants
MemmapTableAddressMissing
The starting address for the memory map wasn’t passed to the boot configurator.
MemmapTableMissing
No memory map wasn’t passed to the boot configurator.
MemmapTablePastRamEnd
The memory map table extends past the end of guest memory.
MemmapTableSetup
Error writing memory map table to guest memory.
StartInfoPastRamEnd
The hvm_start_info structure extends past the end of guest memory.
StartInfoSetup
Error writing hvm_start_info to guest memory.
ModulesAddressMissing
The starting address for the modules descriptions wasn’t passed to the boot configurator.
ModulesSetup
Error writing module descriptions to guest memory.