#[repr(C)]pub struct Elf64_Ehdr {Show 14 fields
pub e_ident: [u8; 16],
pub e_type: Elf64_Half,
pub e_machine: Elf64_Half,
pub e_version: Elf64_Word,
pub e_entry: Elf64_Addr,
pub e_phoff: Elf64_Off,
pub e_shoff: Elf64_Off,
pub e_flags: Elf64_Word,
pub e_ehsize: Elf64_Half,
pub e_phentsize: Elf64_Half,
pub e_phnum: Elf64_Half,
pub e_shentsize: Elf64_Half,
pub e_shnum: Elf64_Half,
pub e_shstrndx: Elf64_Half,
}Available on crate feature
elf and (x86 or x86-64) only.Fields
e_ident: [u8; 16]e_type: Elf64_Halfe_machine: Elf64_Halfe_version: Elf64_Worde_entry: Elf64_Addre_phoff: Elf64_Offe_shoff: Elf64_Offe_flags: Elf64_Worde_ehsize: Elf64_Halfe_phentsize: Elf64_Halfe_phnum: Elf64_Halfe_shentsize: Elf64_Halfe_shnum: Elf64_Halfe_shstrndx: Elf64_HalfTrait Implementations
Sourceimpl ByteValued for Elf64_Ehdr
impl ByteValued for Elf64_Ehdr
Sourcefn from_slice(data: &[u8]) -> Option<&Self>
fn from_slice(data: &[u8]) -> Option<&Self>
Converts a slice of raw data into a reference of
Self. Read moreSourcefn from_mut_slice(data: &mut [u8]) -> Option<&mut Self>
fn from_mut_slice(data: &mut [u8]) -> Option<&mut Self>
Converts a mutable slice of raw data into a mutable reference of
Self. Read moreSourcefn as_mut_slice(&mut self) -> &mut [u8] ⓘ
fn as_mut_slice(&mut self) -> &mut [u8] ⓘ
Converts a mutable reference to
self into a mutable slice of bytes. Read moreSourcefn as_bytes(&mut self) -> VolatileSlice<'_>
fn as_bytes(&mut self) -> VolatileSlice<'_>
Converts a mutable reference to
self into a VolatileSlice. This is
useful because VolatileSlice provides a Bytes<usize> implementation.Sourcefn write_all_to<W>(&self, writer: W) -> Result<(), Error>where
W: Write,
fn write_all_to<W>(&self, writer: W) -> Result<(), Error>where
W: Write,
Writes this
ByteValued’s byte representation to the given Write impl.Sourcefn read_exact_from<R>(reader: R) -> Result<Self, Error>where
R: Read,
fn read_exact_from<R>(reader: R) -> Result<Self, Error>where
R: Read,
Constructs an instance of this
ByteValued by reading from the given Read impl.Sourceimpl Clone for Elf64_Ehdr
impl Clone for Elf64_Ehdr
Sourcefn clone(&self) -> Elf64_Ehdr
fn clone(&self) -> Elf64_Ehdr
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for Elf64_Ehdr
Sourceimpl Debug for Elf64_Ehdr
impl Debug for Elf64_Ehdr
Sourceimpl Default for Elf64_Ehdr
impl Default for Elf64_Ehdr
Sourcefn default() -> Elf64_Ehdr
fn default() -> Elf64_Ehdr
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for Elf64_Ehdr
impl PartialEq for Elf64_Ehdr
Sourcefn eq(&self, other: &Elf64_Ehdr) -> bool
fn eq(&self, other: &Elf64_Ehdr) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for Elf64_Ehdr