#[repr(C)]pub struct Elf64_Nhdr {
pub n_namesz: Elf64_Word,
pub n_descsz: Elf64_Word,
pub n_type: Elf64_Word,
}Available on crate feature
elf and (x86 or x86-64) only.Fields
n_namesz: Elf64_Wordn_descsz: Elf64_Wordn_type: Elf64_WordTrait Implementations
Sourceimpl ByteValued for Elf64_Nhdr
impl ByteValued for Elf64_Nhdr
Sourcefn from_slice(data: &[u8]) -> Option<&Self>
fn from_slice(data: &[u8]) -> Option<&Self>
Converts a slice of raw data into a reference of
Self. Read moreSourcefn from_mut_slice(data: &mut [u8]) -> Option<&mut Self>
fn from_mut_slice(data: &mut [u8]) -> Option<&mut Self>
Converts a mutable slice of raw data into a mutable reference of
Self. Read moreSourcefn as_mut_slice(&mut self) -> &mut [u8] ⓘ
fn as_mut_slice(&mut self) -> &mut [u8] ⓘ
Converts a mutable reference to
self into a mutable slice of bytes. Read moreSourcefn as_bytes(&mut self) -> VolatileSlice<'_>
fn as_bytes(&mut self) -> VolatileSlice<'_>
Converts a mutable reference to
self into a VolatileSlice. This is
useful because VolatileSlice provides a Bytes<usize> implementation.Sourcefn write_all_to<W>(&self, writer: W) -> Result<(), Error>where
W: Write,
fn write_all_to<W>(&self, writer: W) -> Result<(), Error>where
W: Write,
Writes this
ByteValued’s byte representation to the given Write impl.Sourcefn read_exact_from<R>(reader: R) -> Result<Self, Error>where
R: Read,
fn read_exact_from<R>(reader: R) -> Result<Self, Error>where
R: Read,
Constructs an instance of this
ByteValued by reading from the given Read impl.Sourceimpl Clone for Elf64_Nhdr
impl Clone for Elf64_Nhdr
Sourcefn clone(&self) -> Elf64_Nhdr
fn clone(&self) -> Elf64_Nhdr
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for Elf64_Nhdr
Sourceimpl Debug for Elf64_Nhdr
impl Debug for Elf64_Nhdr
Sourceimpl Default for Elf64_Nhdr
impl Default for Elf64_Nhdr
Sourcefn default() -> Elf64_Nhdr
fn default() -> Elf64_Nhdr
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for Elf64_Nhdr
impl PartialEq for Elf64_Nhdr
Sourcefn eq(&self, other: &Elf64_Nhdr) -> bool
fn eq(&self, other: &Elf64_Nhdr) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for Elf64_Nhdr