#[repr(C)]pub struct Elf64_Phdr {
pub p_type: Elf64_Word,
pub p_flags: Elf64_Word,
pub p_offset: Elf64_Off,
pub p_vaddr: Elf64_Addr,
pub p_paddr: Elf64_Addr,
pub p_filesz: Elf64_Xword,
pub p_memsz: Elf64_Xword,
pub p_align: Elf64_Xword,
}Available on crate feature
elf and (x86 or x86-64) only.Fields
p_type: Elf64_Wordp_flags: Elf64_Wordp_offset: Elf64_Offp_vaddr: Elf64_Addrp_paddr: Elf64_Addrp_filesz: Elf64_Xwordp_memsz: Elf64_Xwordp_align: Elf64_XwordTrait Implementations
Sourceimpl ByteValued for Elf64_Phdr
impl ByteValued for Elf64_Phdr
Sourcefn from_slice(data: &[u8]) -> Option<&Self>
fn from_slice(data: &[u8]) -> Option<&Self>
Converts a slice of raw data into a reference of
Self. Read moreSourcefn from_mut_slice(data: &mut [u8]) -> Option<&mut Self>
fn from_mut_slice(data: &mut [u8]) -> Option<&mut Self>
Converts a mutable slice of raw data into a mutable reference of
Self. Read moreSourcefn as_mut_slice(&mut self) -> &mut [u8] ⓘ
fn as_mut_slice(&mut self) -> &mut [u8] ⓘ
Converts a mutable reference to
self into a mutable slice of bytes. Read moreSourcefn as_bytes(&mut self) -> VolatileSlice<'_>
fn as_bytes(&mut self) -> VolatileSlice<'_>
Converts a mutable reference to
self into a VolatileSlice. This is
useful because VolatileSlice provides a Bytes<usize> implementation.Sourcefn write_all_to<W>(&self, writer: W) -> Result<(), Error>where
W: Write,
fn write_all_to<W>(&self, writer: W) -> Result<(), Error>where
W: Write,
Writes this
ByteValued’s byte representation to the given Write impl.Sourcefn read_exact_from<R>(reader: R) -> Result<Self, Error>where
R: Read,
fn read_exact_from<R>(reader: R) -> Result<Self, Error>where
R: Read,
Constructs an instance of this
ByteValued by reading from the given Read impl.Sourceimpl Clone for Elf64_Phdr
impl Clone for Elf64_Phdr
Sourcefn clone(&self) -> Elf64_Phdr
fn clone(&self) -> Elf64_Phdr
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for Elf64_Phdr
Sourceimpl Debug for Elf64_Phdr
impl Debug for Elf64_Phdr
Sourceimpl Default for Elf64_Phdr
impl Default for Elf64_Phdr
Sourcefn default() -> Elf64_Phdr
fn default() -> Elf64_Phdr
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for Elf64_Phdr
impl PartialEq for Elf64_Phdr
Sourcefn eq(&self, other: &Elf64_Phdr) -> bool
fn eq(&self, other: &Elf64_Phdr) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for Elf64_Phdr