pub type Elf64_Nhdr = elf64_note;Available on (x86 or x86-64) and crate feature
elf only.Aliased Type
#[repr(C)]pub struct Elf64_Nhdr {
pub n_namesz: u32,
pub n_descsz: u32,
pub n_type: u32,
}Fields
n_namesz: u32n_descsz: u32n_type: u32Trait Implementations
Sourceimpl ByteValued for Elf64_Nhdr
impl ByteValued for Elf64_Nhdr
Sourcefn from_slice(data: &[u8]) -> Option<&Self>
fn from_slice(data: &[u8]) -> Option<&Self>
Converts a slice of raw data into a reference of
Self. Read moreSourcefn from_mut_slice(data: &mut [u8]) -> Option<&mut Self>
fn from_mut_slice(data: &mut [u8]) -> Option<&mut Self>
Converts a mutable slice of raw data into a mutable reference of
Self. Read moreSourcefn as_mut_slice(&mut self) -> &mut [u8] ⓘ
fn as_mut_slice(&mut self) -> &mut [u8] ⓘ
Converts a mutable reference to
self into a mutable slice of bytes. Read moreSourcefn as_bytes(&mut self) -> VolatileSlice<'_>
fn as_bytes(&mut self) -> VolatileSlice<'_>
Converts a mutable reference to
self into a VolatileSlice. This is
useful because VolatileSlice provides a Bytes<usize> implementation. Read more