Module loader

Module loader 

Traits and structs for loading kernels into guest memory.

  • KernelLoader: load kernel image into guest memory.
  • KernelLoaderResult: structure passed to the VMM to assist zero page construction and boot environment setup.
  • Elf: elf image loader.
  • BzImage: bzImage loader.
  • PE: PE image loader.

Re-exports

pub use crate::cmdline::Cmdline;
pub use elf::*;elf and (x86 or x86-64)
pub use bzimage::*;bzimage and (x86 or x86-64)

Modules

bootparamx86 or x86-64
bzimagebzimage and (x86 or x86-64)
Traits and structs for loading bzimage kernels into guest memory.
elfelf and (x86 or x86-64)
Traits and structs for loading elf image kernels into guest memory.

Structs

KernelLoaderResult
Result of KernelLoader.load().

Enums

Error
Kernel loader errors.

Traits

KernelLoader
Trait that specifies kernel image loading support.

Functions

load_cmdline
Writes the command line string to the given guest memory slice.

Type Aliases

Result
A specialized Result type for the kernel loader.