Module elf

Module elf 

Available on crate feature elf and (x86 or x86-64) only.
Traits and structs for loading elf image kernels into guest memory.

Modules

start_info

Structs

Elf
Raw ELF (a.k.a. vmlinux) kernel image support.

Enums

Error
Elf kernel loader errors.
PvhBootCapability
Availability of PVH entry point in the kernel, which allows the VMM to use the PVH boot protocol to start guests.