#[repr(C)]pub struct hvm_modlist_entry {
pub paddr: u64,
pub size: u64,
pub cmdline_paddr: u64,
pub reserved: u64,
}Available on crate feature
elf and (x86 or x86-64) only.Fields
paddr: u64size: u64cmdline_paddr: u64reserved: u64Trait Implementations
Sourceimpl ByteValued for hvm_modlist_entry
Available on (crate features bzimage or elf) and (crate features bzimage or elf or pe) only.
impl ByteValued for hvm_modlist_entry
Available on (crate features
bzimage or elf) and (crate features bzimage or elf or pe) only.Sourcefn from_slice(data: &[u8]) -> Option<&Self>
fn from_slice(data: &[u8]) -> Option<&Self>
Converts a slice of raw data into a reference of
Self. Read moreSourcefn from_mut_slice(data: &mut [u8]) -> Option<&mut Self>
fn from_mut_slice(data: &mut [u8]) -> Option<&mut Self>
Converts a mutable slice of raw data into a mutable reference of
Self. Read moreSourcefn as_mut_slice(&mut self) -> &mut [u8] ⓘ
fn as_mut_slice(&mut self) -> &mut [u8] ⓘ
Converts a mutable reference to
self into a mutable slice of bytes. Read moreSourcefn as_bytes(&mut self) -> VolatileSlice<'_>
fn as_bytes(&mut self) -> VolatileSlice<'_>
Converts a mutable reference to
self into a VolatileSlice. This is
useful because VolatileSlice provides a Bytes<usize> implementation.Sourcefn write_all_to<W>(&self, writer: W) -> Result<(), Error>where
W: Write,
fn write_all_to<W>(&self, writer: W) -> Result<(), Error>where
W: Write,
Writes this
ByteValued’s byte representation to the given Write impl.Sourcefn read_exact_from<R>(reader: R) -> Result<Self, Error>where
R: Read,
fn read_exact_from<R>(reader: R) -> Result<Self, Error>where
R: Read,
Constructs an instance of this
ByteValued by reading from the given Read impl.Sourceimpl Clone for hvm_modlist_entry
impl Clone for hvm_modlist_entry
Sourcefn clone(&self) -> hvm_modlist_entry
fn clone(&self) -> hvm_modlist_entry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for hvm_modlist_entry
Sourceimpl Debug for hvm_modlist_entry
impl Debug for hvm_modlist_entry
Sourceimpl Default for hvm_modlist_entry
impl Default for hvm_modlist_entry
Sourcefn default() -> hvm_modlist_entry
fn default() -> hvm_modlist_entry
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for hvm_modlist_entry
impl PartialEq for hvm_modlist_entry
Sourcefn eq(&self, other: &hvm_modlist_entry) -> bool
fn eq(&self, other: &hvm_modlist_entry) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for hvm_modlist_entry