#[repr(C)]pub struct hvm_start_info {
pub magic: u32,
pub version: u32,
pub flags: u32,
pub nr_modules: u32,
pub modlist_paddr: u64,
pub cmdline_paddr: u64,
pub rsdp_paddr: u64,
pub memmap_paddr: u64,
pub memmap_entries: u32,
pub reserved: u32,
}Available on crate feature
elf and (x86 or x86-64) only.Expand description
Start of day structure passed to PVH guests and to HVM guests in %ebx.
A 0 value in any address field means not present.
Version 0 ends after rsdp_paddr; fields from memmap_paddr onward
are only present in version 1+.
Fields
magic: u32version: u32flags: u32nr_modules: u32modlist_paddr: u64cmdline_paddr: u64rsdp_paddr: u64memmap_paddr: u64memmap_entries: u32reserved: u32Trait Implementations
Sourceimpl ByteValued for hvm_start_info
Available on (crate features bzimage or elf) and (crate features bzimage or elf or pe) only.
impl ByteValued for hvm_start_info
Available on (crate features
bzimage or elf) and (crate features bzimage or elf or pe) only.Sourcefn from_slice(data: &[u8]) -> Option<&Self>
fn from_slice(data: &[u8]) -> Option<&Self>
Converts a slice of raw data into a reference of
Self. Read moreSourcefn from_mut_slice(data: &mut [u8]) -> Option<&mut Self>
fn from_mut_slice(data: &mut [u8]) -> Option<&mut Self>
Converts a mutable slice of raw data into a mutable reference of
Self. Read moreSourcefn as_mut_slice(&mut self) -> &mut [u8] ⓘ
fn as_mut_slice(&mut self) -> &mut [u8] ⓘ
Converts a mutable reference to
self into a mutable slice of bytes. Read moreSourcefn as_bytes(&mut self) -> VolatileSlice<'_>
fn as_bytes(&mut self) -> VolatileSlice<'_>
Converts a mutable reference to
self into a VolatileSlice. This is
useful because VolatileSlice provides a Bytes<usize> implementation.Sourcefn write_all_to<W>(&self, writer: W) -> Result<(), Error>where
W: Write,
fn write_all_to<W>(&self, writer: W) -> Result<(), Error>where
W: Write,
Writes this
ByteValued’s byte representation to the given Write impl.Sourcefn read_exact_from<R>(reader: R) -> Result<Self, Error>where
R: Read,
fn read_exact_from<R>(reader: R) -> Result<Self, Error>where
R: Read,
Constructs an instance of this
ByteValued by reading from the given Read impl.Sourceimpl Clone for hvm_start_info
impl Clone for hvm_start_info
Sourcefn clone(&self) -> hvm_start_info
fn clone(&self) -> hvm_start_info
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for hvm_start_info
Sourceimpl Debug for hvm_start_info
impl Debug for hvm_start_info
Sourceimpl Default for hvm_start_info
impl Default for hvm_start_info
Sourcefn default() -> hvm_start_info
fn default() -> hvm_start_info
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for hvm_start_info
impl PartialEq for hvm_start_info
Sourcefn eq(&self, other: &hvm_start_info) -> bool
fn eq(&self, other: &hvm_start_info) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for hvm_start_info